@@ -5,7 +5,7 @@
 %%% Created : 16 Feb 2003 by Alexey Shchepin <alexey@proces-one.net>
 %%%
 %%%
-%%% Copyright (C) 2002-2020 ProcessOne, SARL. All Rights Reserved.
+%%% Copyright (C) 2002-2021 ProcessOne, SARL. All Rights Reserved.
 %%%
 %%% Licensed under the Apache License, Version 2.0 (the "License");
 %%% you may not use this file except in compliance with the License.
@@ -28,7 +28,7 @@
 -compile(no_native).
 
 -export([start/0, load_nif/0, tolower/1, nameprep/1,
-	 nodeprep/1, resourceprep/1]).
+	 nodeprep/1, resourceprep/1, tolower_nofilter/1]).
 
 %%%===================================================================
 %%% API functions
@@ -43,6 +43,7 @@ load_nif() ->
     SOPath = p1_nif_utils:get_so_path(?MODULE, [stringprep], "stringprep"),
     case catch erlang:load_nif(SOPath, 0) of
         ok -> ok;
+        {error, {reload, _}} -> ok;
         Err -> error_logger:warning_msg("unable to load stringprep NIF: ~p~n", [Err]),
                {error, unable_to_load_nif}
     end.
@@ -51,6 +52,10 @@ load_nif() ->
 tolower(_String) ->
     erlang:nif_error(nif_not_loaded).
 
+-spec tolower_nofilter(iodata()) -> binary() | error.
+tolower_nofilter(_String) ->
+    erlang:nif_error(nif_not_loaded).
+
 -spec nameprep(iodata()) -> binary() | error.
 nameprep(_String) ->
     erlang:nif_error(nif_not_loaded).
